@import "../../../../../css/_mixins.scss";
@import "../../../../../css/_trx_addons.vars.scss";

/* Elementor specific rules */
.elementor-element-edit-mode .sc_layouts_blog_item > div {
	min-width: 60px;
	min-height: 16px;
}
.elementor-element-edit-mode .sc_layouts_blog_item_featured[class*="hover_"] {
	display: block;
}
.elementor-element-edit-mode .sc_layouts_blog_item_featured img {
	max-width: none;
	width: 100%;
}
.elementor-element .elementor-widget-container .sc_layouts_blog_item {
	@include transition-properties(background,background-image,background-color,border,border-radius,box-shadow);
}

/* Gutenberg specific rules */
.editor-block-list__layout .editor-block-list__block[data-type="trx-addons/layouts-blog-item"][class*="sc_layouts_blog_item_position_"]:not(.sc_layouts_blog_item_position_static) .is-block-container,
.editor-block-list__layout .editor-block-list__block[data-type="trx-addons/layouts-blog-item"][class*="sc_layouts_blog_item_position_"]:not(.sc_layouts_blog_item_position_static) .editor-block-list__block-edit {
	margin-top: 0;
	margin-bottom: 0;
}


/* Common rules */
.sc_layouts_blog_item .hide_overflow {
	max-height: 1.35em;
	overflow: hidden;
}
.sc_layouts_blog_item_featured {
	overflow: hidden;	// To correct border-radius
}
.sc_layouts_blog_item_featured .post_featured {
	margin-bottom: 0;
}
.sc_layouts_blog_item_featured_mask .post_featured:after {
	content: ' ';
	background-color: #000;
	opacity: 0.3;
	@include transition-properties(opacity,background-color);
	@include abs-cover(2);
}
.sc_layouts_blog_item_featured_mask:hover .post_featured:after {
	opacity: 0.1;
}
.sc_layouts_blog_item_title .post_title {
	margin: 0;
	line-height: 1.15em;
}
.sc_layouts_blog_item .post_title > a,
.sc_layouts_blog_item .post_meta > a,
.sc_layouts_blog_item .post_meta > span,
.sc_layouts_blog_item .post_button a,
.sc_layouts_blog_item .post_excerpt > *,
.sc_layouts_blog_item .post_custom > * {
	@include transition-properties(color,background-color,opacity);
}

.sc_layouts_blog_item .post_button {
	white-space: nowrap;
}
.sc_layouts_blog_item .post_button .sc_button:not(.sc_button_simple) {
	padding: 1em 2em;
}
.sc_layouts_blog_item .post_button a,
.sc_layouts_blog_item .post_meta > a,
.sc_layouts_blog_item .post_meta > span {
	display: inline-block;
	vertical-align: top;
}

[class*="sc_layouts_blog_item_position_"]:not(.sc_layouts_blog_item_position_static) .post_meta {
	margin:  0;
}

.sc_layouts_blog_item_position_tl { @include abs-lt; }
.sc_layouts_blog_item_position_tc {	@include abs-ct; }
.sc_layouts_blog_item_position_tr { @include abs-rt; }

.sc_layouts_blog_item_position_ml { @include abs-lc; }
.sc_layouts_blog_item_position_mc {	@include abs-cc; min-width: 75% !important; }
.sc_layouts_blog_item_position_mr { @include abs-rc; }

.sc_layouts_blog_item_position_bl { @include abs-lb; }
.sc_layouts_blog_item_position_bc {	@include abs-cb; }
.sc_layouts_blog_item_position_br { @include abs-rb; }

[class*="sc_layouts_blog_item_position_"]:not(.sc_layouts_blog_item_position_static) {
	position: absolute;
	z-index: 12;
	max-width: 90%;
	min-width: 10px;
}

.sc_layouts_blog_item_position_tl,
.sc_layouts_blog_item_position_ml,
.sc_layouts_blog_item_position_bl {
	text-align: left;
}
.sc_layouts_blog_item_position_tc,
.sc_layouts_blog_item_position_mc,
.sc_layouts_blog_item_position_bc {
	text-align: center;
}
.sc_layouts_blog_item_position_tr,
.sc_layouts_blog_item_position_mr,
.sc_layouts_blog_item_position_br {
	text-align: right;
}
